@@ -28,16 +28,13 @@ as enum, six, yaml.
 # pylint: disable=g-import-not-at-top
 
 from pyglove.core import *
-from pyglove import generators
+from pyglove.ext import *
 
-evolution = generators.evolution
-early_stopping = generators.early_stopping
-
- # Placeholder for Google-internal imports.
+# Placeholder for Google-internal imports.
 
 # pylint: enable=g-import-not-at-top
 # pylint: enable=reimported
 # pylint: enable=unused-import
 # pylint: enable=g-bad-import-order
 
-__version__ = "0.2.0"
+__version__ = "0.4.1"
