@@ -27,19 +27,17 @@ to symbolic program declaration, program manipulation, program generation and
 runtime type checking. It also introduced features in advanced function binding
 and class detouring, which may be applicable to general Python coding scenarios.
 
-Here lists the files included in the core PyGlove library:
+Here lists the sub-modules included in the core PyGlove library:
 
   pyglove/core
-   |__ symbolic.py     :  Symbolic program constructs and operations.
-   |__ wrapping.py     :  Converting existing classes into symbolic classes.
-   |__ typing.py       :  Runtime type check and value validation.
-   |__ geno.py         :  Genome types for program generation/manipulation.
-   |__ hyper.py        :  Encoding/Decoding between a program and a genome.
-   |__ composing.py    :  Dealing with symbolic compositions.
-   |__ tuning.py       :  Interface for program tuning with a local backend.
-   |__ detouring.py    :  Detouring classes creation without symbolic types.
-   |__ patching.py     :  Patching a program with URL-like strings.
-   |__ object_utils.py :  Utility libary on operating with Python objects.
+   |__ symbolic        :  Symbolic program constructs and operations.
+   |__ typing          :  Runtime type check and value validation.
+   |__ geno            :  Genome types for program generation/manipulation.
+   |__ hyper           :  Encoding/Decoding between a program and a genome.
+   |__ tuning          :  Interface for program tuning with a local backend.
+   |__ detouring       :  Detouring classes creation without symbolic types.
+   |__ patching        :  Patching a program with URL-like strings.
+   |__ object_utils    :  Utility libary on operating with Python objects.
 
 """
 
@@ -60,11 +58,12 @@ from pyglove.core import symbolic
 # Global flags.
 allow_empty_field_description = symbolic.allow_empty_field_description
 allow_repeated_class_registration = symbolic.allow_repeated_class_registration
-set_stacktrace_limit = symbolic.set_stacktrace_limit
+set_origin_stacktrace_limit = symbolic.set_origin_stacktrace_limit
 
 # Context manager for scoped flags.
-allow_partial = symbolic.allow_partial_values
+allow_partial = symbolic.allow_partial
 allow_writable_accessors = symbolic.allow_writable_accessors
+auto_call_functors = symbolic.auto_call_functors
 notify_on_change = symbolic.notify_on_change
 enable_type_check = symbolic.enable_type_check
 track_origin = symbolic.track_origin
@@ -81,28 +80,57 @@ List = symbolic.List
 list = List   # pylint: disable=redefined-builtin
 
 Object = symbolic.Object
+ClassWrapper = symbolic.ClassWrapper
 Functor = symbolic.Functor
 
 # Decorator for declaring symbolic. members for `pg.Object`.
 members = symbolic.members
 
+# Decorator for updating the __init__ signature of `pg.Object`.
+use_init_args = symbolic.use_init_args
+
 #
 # Methods for making symbolic types.
 #
 
+# Function/Decorator for symbolizing existing types.
+symbolize = symbolic.symbolize
+
 # Decorator for converting a function into `pg.Functor`.
 functor = symbolic.functor
 
 # Method for making a functor class out from a function.
 functor_class = symbolic.functor_class
 
+# Function for wrapping a single class.
+wrap = symbolic.wrap
+
+# Function for wrapping multiple classes under a module.
+wrap_module = symbolic.wrap_module
+
+# Decorator for creating compound class.
+compound = symbolic.compound
+
+# Function for making compound class.
+compound_class = symbolic.compound_class
+
 # Method for declaring a boilerplated class from a symbolic instance.
 boilerplate_class = symbolic.boilerplate_class
 
+
+#
+# Context manager for swapping wrapped class with their wrappers.
+#
+
+apply_wrappers = symbolic.apply_wrappers
+
+
 # Methods for symbolic operations.
 eq = symbolic.eq
 ne = symbolic.ne
-hash = symbolic.sym_hash  # pylint: disable=redefined-builtin
+lt = symbolic.lt
+gt = symbolic.gt
+hash = symbolic.hash  # pylint: disable=redefined-builtin
 clone = symbolic.clone
 
 # Methods for querying symbolic types.
@@ -137,38 +165,15 @@ FieldUpdate = symbolic.FieldUpdate
 Insertion = symbolic.Insertion
 WritePermissionError = symbolic.WritePermissionError
 
-#
-# Symbols from 'wrapping.py'.
-#
+# Contextual value marker.
+ContextualValue = symbolic.ContextualValue
+ContextualGetter = symbolic.ContextualGetter
 
-from pyglove.core import wrapping
-
-ClassWrapper = wrapping.ClassWrapper
-
-# Decorator or method for symbolizing an existing class or function.
-symbolize = wrapping.symbolize
-
-
-# Methods for wrapping existing classes an swap them with their wrappers.
-
-# Method for making a symbolic class wrapper from a regular Python class.
-wrap = wrapping.wrap
-
-# Wrap classes within a module in batch.
-wrap_module = wrapping.wrap_module
-
-# Context manager for swapping wrapped class with their wrappers.
-apply_wrappers = wrapping.apply_wrappers
-
-
-#
-# Symbols from 'composing.py'
-#
-
-from pyglove.core import composing
-
-mutate = composing.mutate
+# Decorator for making contextual getters.
+contextual_getter = symbolic.contextual_getter
 
+# Context object for computing contextual attribute.
+GetAttributeContext = symbolic.GetAttributeContext
 
 #
 # Symbols from 'typing.py'
@@ -217,6 +222,7 @@ oneof = hyper.oneof
 manyof = hyper.manyof
 permutate = hyper.permutate
 floatv = hyper.floatv
+evolve = hyper.evolve
 
 # Aliases for backward compatibility.
 one_of = hyper.one_of
@@ -262,7 +268,7 @@ patch_on_path = patching.patch_on_path
 patch_on_value = patching.patch_on_value
 patch_on_type = patching.patch_on_type
 patch_on_member = patching.patch_on_member
-object_factory = patching.object_factory
+ObjectFactory = patching.ObjectFactory
 
 
 #
@@ -276,11 +282,13 @@ MISSING_VALUE = object_utils.MISSING_VALUE
 Formattable = object_utils.Formattable
 MaybePartial = object_utils.MaybePartial
 JSONConvertible = object_utils.JSONConvertible
+DocStr = object_utils.DocStr
 
+registered_types = object_utils.registered_types
 is_partial = object_utils.is_partial
 format = object_utils.format   # pylint: disable=redefined-builtin
-print = object_utils.printv    # pylint: disable=redefined-builtin
-
+print = object_utils.print    # pylint: disable=redefined-builtin
+docstr = object_utils.docstr
 
 #
 # Symbols from `logging.py`.
@@ -289,7 +297,6 @@ print = object_utils.printv    # pylint: disable=redefined-builtin
 from pyglove.core import logging
 
 
-
 # pylint: enable=g-import-not-at-top
 # pylint: enable=reimported
 # pylint: enable=unused-import
